import { PreviewState } from 'decap-cms-lib-util';
import { GitHubBackend } from 'decap-cms-backend-github';
import { GitLabBackend } from 'decap-cms-backend-gitlab';
import { BitbucketBackend, API as BitBucketAPI } from 'decap-cms-backend-bitbucket';
import GitHubAPI from './GitHubAPI';
import GitLabAPI from './GitLabAPI';
import AuthenticationPage from './AuthenticationPage';
import type { Client } from './netlify-lfs-client';
import type { ApiRequest, AssetProxy, PersistOptions, Entry, Cursor, Implementation, DisplayURL, User, Credentials, Config, ImplementationFile } from 'decap-cms-lib-util';
type NetlifyIdentity = {
    logout: () => void;
    currentUser: () => User;
    on: (event: string, args: unknown) => void;
    init: () => void;
    store: {
        user: unknown;
        modal: {
            page: string;
        };
        saving: boolean;
    };
};
type AuthClient = {
    logout: () => void;
    currentUser: () => unknown;
    login?(email: string, password: string, remember?: boolean): Promise<unknown>;
    clearStore: () => void;
};
declare global {
    interface Window {
        netlifyIdentity?: NetlifyIdentity;
    }
}
export default class GitGateway implements Implementation {
    config: Config;
    api?: GitHubAPI | GitLabAPI | BitBucketAPI;
    branch: string;
    squashMerges: boolean;
    cmsLabelPrefix: string;
    mediaFolder: string;
    transformImages: boolean;
    gatewayUrl: string;
    netlifyLargeMediaURL: string;
    backendType: string | null;
    apiUrl: string;
    authClient?: AuthClient;
    backend: GitHubBackend | GitLabBackend | BitbucketBackend | null;
    acceptRoles?: string[];
    tokenPromise?: () => Promise<string>;
    _largeMediaClientPromise?: Promise<Client>;
    options: {
        proxied: boolean;
        API: GitHubAPI | GitLabAPI | BitBucketAPI | null;
        initialWorkflowStatus: string;
    };
    constructor(config: Config, options?: {});
    isGitBackend(): boolean;
    status(): Promise<{
        auth: {
            status: boolean;
        };
        api: {
            status: any;
            statusPage: string;
        };
    }>;
    getAuthClient(): Promise<AuthClient>;
    requestFunction: (req: ApiRequest) => Promise<any>;
    authenticate(credentials: Credentials): Promise<import("decap-cms-lib-util/dist/esm/implementation").User>;
    restoreUser(): Promise<import("decap-cms-lib-util/dist/esm/implementation").User>;
    authComponent(): typeof AuthenticationPage;
    logout(): Promise<void>;
    getToken(): Promise<string>;
    entriesByFolder(folder: string, extension: string, depth: number): Promise<import("decap-cms-lib-util/dist/esm/implementation").ImplementationEntry[]>;
    allEntriesByFolder(folder: string, extension: string, depth: number, pathRegex?: RegExp): Promise<import("decap-cms-lib-util/dist/esm/implementation").ImplementationEntry[]>;
    entriesByFiles(files: ImplementationFile[]): Promise<import("decap-cms-lib-util/dist/esm/implementation").ImplementationEntry[]>;
    getEntry(path: string): Promise<{
        file: {
            path: string;
            id: null;
        };
        data: string;
    } | {
        file: {
            path: string;
            id: null;
        };
        data: string;
    }>;
    unpublishedEntryDataFile(collection: string, slug: string, path: string, id: string): Promise<string>;
    isLargeMediaFile(path: string): Promise<boolean>;
    unpublishedEntryMediaFile(collection: string, slug: string, path: string, id: string): Promise<{
        id: string;
        displayURL: string;
        path: string;
        name: string;
        size: number;
        file: File;
    } | {
        id: string;
        name: string;
        path: string;
        url: string;
        displayURL: string;
        file: File;
        size: number;
    }>;
    getMedia(mediaFolder?: string): Promise<{
        id: string;
        name: string;
        path: string;
        displayURL: {
            id: string;
            path: string;
        };
    }[]>;
    getLargeMediaClient(): Promise<Client>;
    _getLargeMediaClient(): Promise<any>;
    getLargeMediaDisplayURL({ path, id }: {
        path: string;
        id: string | null;
    }, branch?: string): Promise<{
        url: string;
        blob: Blob;
    }>;
    getMediaDisplayURL(displayURL: DisplayURL): Promise<string>;
    getMediaFile(path: string): Promise<{
        id: string;
        name: string;
        path: string;
        url: string;
        displayURL: string;
        file: File;
        size: number;
    }>;
    persistEntry(entry: Entry, options: PersistOptions): Promise<any>;
    persistMedia(mediaFile: AssetProxy, options: PersistOptions): Promise<{
        id: string;
        name: string;
        size: number;
        displayURL: string;
        path: string;
    }>;
    deleteFiles(paths: string[], commitMessage: string): any;
    getDeployPreview(collection: string, slug: string): Promise<{
        url: string;
        status: PreviewState;
    } | null>;
    unpublishedEntries(): Promise<string[]>;
    unpublishedEntry({ id, collection, slug }: {
        id?: string;
        collection?: string;
        slug?: string;
    }): Promise<{
        collection: string;
        slug: string;
        status: string;
        diffs: {
            path: string;
            newFile: boolean;
            id: string;
        }[];
        updatedAt: string;
        pullRequestAuthor: string | undefined;
    }>;
    updateUnpublishedEntryStatus(collection: string, slug: string, newStatus: string): Promise<any>;
    deleteUnpublishedEntry(collection: string, slug: string): Promise<any>;
    publishUnpublishedEntry(collection: string, slug: string): Promise<any>;
    traverseCursor(cursor: Cursor, action: string): Promise<{
        entries: import("decap-cms-lib-util/dist/esm/implementation").ImplementationEntry[];
        cursor: Cursor;
    }>;
}
export {};
